@@ -359,7 +359,7 @@ C -------- WHEN A FAIL HAS OCCURED, WE RETURN WITH IDID=-1
       END IF
 C -------- CALL TO CORE INTEGRATOR ------------
       CALL DP86CO(N,FCN,X,Y,XEND,HMAX,H,RTOL,ATOL,ITOL,IPRINT,
-     &   SOLOUT,IOUT,IDID,NMAX,UROUND,METH,NSTIFF,SAFE,BETA,FAC1,FAC2,
+     &   SOLOUT,IOUT,IDID,NMAX,UROUND,NSTIFF,SAFE,BETA,FAC1,FAC2,
      &   WORK(IEK1),WORK(IEK2),WORK(IEK3),WORK(IEK4),WORK(IEK5),
      &   WORK(IEK6),WORK(IEK7),WORK(IEK8),WORK(IEK9),WORK(IEK10),
      &   WORK(IEY1),WORK(IECO),IWORK(ICOMP),NRDENS,RPAR,IPAR,
@@ -378,7 +378,7 @@ C
 C  ----- ... AND HERE IS THE CORE INTEGRATOR  ----------
 C
       SUBROUTINE DP86CO(N,FCN,X,Y,XEND,HMAX,H,RTOL,ATOL,ITOL,IPRINT,
-     &   SOLOUT,IOUT,IDID,NMAX,UROUND,METH,NSTIFF,SAFE,BETA,FAC1,FAC2,
+     &   SOLOUT,IOUT,IDID,NMAX,UROUND,NSTIFF,SAFE,BETA,FAC1,FAC2,
      &   K1,K2,K3,K4,K5,K6,K7,K8,K9,K10,Y1,CONT,ICOMP,NRD,RPAR,IPAR,
      &   NFCN,NSTEP,NACCPT,NREJCT)
 C ----------------------------------------------------------
@@ -581,7 +581,7 @@ C --- INITIAL PREPARATIONS
       CALL FCN(N,X,Y,K1,RPAR,IPAR)
       HMAX=ABS(HMAX)     
       IORD=8  
-      IF (H.EQ.0.D0) H=HINIT(N,FCN,X,Y,XEND,POSNEG,K1,K2,K3,IORD,
+      IF (H.EQ.0.D0) H=HINIT(N,FCN,X,Y,POSNEG,K1,K2,K3,IORD,
      &                       HMAX,ATOL,RTOL,ITOL,RPAR,IPAR)
       NFCN=NFCN+2
       REJECT=.FALSE.
@@ -841,7 +841,7 @@ C --- FAIL EXIT
       RETURN
       END
 C
-      FUNCTION HINIT(N,FCN,X,Y,XEND,POSNEG,F0,F1,Y1,IORD,
+      FUNCTION HINIT(N,FCN,X,Y,POSNEG,F0,F1,Y1,IORD,
      &                       HMAX,ATOL,RTOL,ITOL,RPAR,IPAR)
 C ----------------------------------------------------------
 C ----  COMPUTATION OF AN INITIAL STEP SIZE GUESS
